from setuptools import setup, find_packages

setup(
    name='ex1_6',
    version='0.1',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        # List any dependencies here
    ],
)
